@@ -12,7 +12,7 @@ from bluesky.plans import scan
 from ophyd.sim import motor, det
 
 from bluesky_widgets.utils.streaming import stream_documents_into_runs
-from bluesky_widgets.models.plot_builders import AutoLines
+from bluesky_widgets.models.auto_plot_builders import AutoLines
 from bluesky_widgets.headless.figures import HeadlessFigures
 from bluesky_widgets.examples.utils.generate_msgpack_data import get_catalog
 
